@@ -1,6 +1,6 @@
 package HTML::Shakan;
 use Any::Moose;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 use Carp ();
 
 use FormValidator::Lite 'Email', 'URL', 'Date', 'File';
@@ -149,6 +149,13 @@ sub render {
     $self->renderer()->render($self);
 }
 
+sub render_field {
+    my ( $self, $name ) = @_;
+    my ( $field, ) = grep { $_->name eq $name } $self->fields;
+    return unless $field;
+    return $self->widgets->render( $self, $field );
+}
+
 sub fillin_param {
     my ($self, $key) = @_;
     $self->fillin_params->{$key};
@@ -386,6 +393,20 @@ If you want to know about shakan, please see L<http://www.konuma-sakan.com/index
 
 左官 should pronounce 'sakan', formally. but, edokko pronounce 左官 as shakan.
 
+=head1 METHODS
+
+=over 4
+
+=item $shakan->render();
+
+render form.
+
+=item $shakan->render_field($name);
+
+render partial form named $name.
+
+=back
+
 =head1 AUTHOR
 
 Tokuhiro Matsuno E<lt>tokuhirom  slkjfd gmail.comE<gt>
